@@ -1748,6 +1748,9 @@ describe('deepEqual()', () => {
         expect(Hoek.deepEqual({ a: 1, b: 2, [sym]: 3 }, { a: 1, b: 2 })).to.be.false();
         expect(Hoek.deepEqual({ a: 1, b: 2, [sym]: 3 }, { a: 1, b: 2 }, { skip: [sym] })).to.be.true();
         expect(Hoek.deepEqual({ a: 1, b: 2, [sym]: 3, [Symbol('other')]: true }, { a: 1, b: 2 }, { skip: [sym] })).to.be.false();
+
+        expect(Hoek.deepEqual({ a: 1, b: 2 }, { a: 1 }, { skip: ['a'] })).to.be.false();
+        expect(Hoek.deepEqual({ a: 1 }, { a: 1, b: 2 }, { skip: ['a'] })).to.be.false();
     });
 
     it('handles circular dependency', () => {
@@ -2133,6 +2136,9 @@ describe('contain()', () => {
         expect(Hoek.contain('ab', ['a', 'b', 'c'])).to.be.false();
         expect(Hoek.contain('ab', ['a', 'b', 'c'], { only: true })).to.be.false();
         expect(Hoek.contain('ab', ['a', 'b', 'c'], { only: true, once: true })).to.be.false();
+
+        expect(Hoek.contain('ab', ['c'], { part: true })).to.be.false();
+        expect(Hoek.contain('ab', ['b'], { part: true })).to.be.true();
     });
 
     it('tests arrays', () => {
@@ -2179,6 +2185,9 @@ describe('contain()', () => {
         expect(Hoek.contain(['a', 'b'], ['a', 'b', 'c'])).to.be.false();
         expect(Hoek.contain(['a', 'b'], ['a', 'b', 'c'], { only: true })).to.be.false();
         expect(Hoek.contain(['a', 'b'], ['a', 'b', 'c'], { only: true, once: true })).to.be.false();
+
+        expect(Hoek.contain(['a', 'b'], ['c'], { part: true })).to.be.false();
+        expect(Hoek.contain(['a', 'b'], ['b'], { part: true })).to.be.true();
     });
 
     it('tests objects', () => {
@@ -2223,6 +2232,9 @@ describe('contain()', () => {
         expect(Hoek.contain({ a: 'foo', b: 'bar' }, { a: 'foo', b: 'bar', c: 'x' })).to.be.false();
         expect(Hoek.contain({ a: 'foo', b: 'bar' }, { a: 'foo', b: 'bar', c: 'x' }, { only: true })).to.be.false();
 
+        expect(Hoek.contain({ a: 1, b: 2 }, ['c'], { part: true })).to.be.false();
+        expect(Hoek.contain({ a: 1, b: 2 }, ['b'], { part: true })).to.be.true();
+
         // Getter check
 
         {
@@ -2311,6 +2323,21 @@ describe('contain()', () => {
         expect(Hoek.contain([sym], Symbol())).to.be.false();
         expect(Hoek.contain({ [sym]: 1 }, Symbol())).to.be.false();
     });
+
+    it('compares error keys', () => {
+
+        const error = new Error('test');
+        expect(Hoek.contain(error, { x: 1 })).to.be.false();
+        expect(Hoek.contain(error, { x: 1 }, { part: true })).to.be.false();
+
+        error.x = 1;
+
+        expect(Hoek.contain(error, { x: 1 })).to.be.true();
+        expect(Hoek.contain(error, { x: 1 }, { part: true })).to.be.true();
+
+        expect(Hoek.contain(error, { x: 1, y: 2 })).to.be.false();
+        expect(Hoek.contain(error, { x: 1, y: 2 }, { part: true })).to.be.true();
+    });
 });
 
 describe('flatten()', () => {
@@ -2740,3 +2767,32 @@ describe('stringify()', () => {
         expect(Hoek.stringify(obj)).to.contain('Cannot display object');
     });
 });
+
+describe('isPromise()', () => {
+
+    it('determines if an object is a promise', async () => {
+
+        expect(Hoek.isPromise({})).to.be.false();
+        expect(Hoek.isPromise(null)).to.be.false();
+        expect(Hoek.isPromise(false)).to.be.false();
+        expect(Hoek.isPromise(0)).to.be.false();
+        expect(Hoek.isPromise('')).to.be.false();
+        expect(Hoek.isPromise({ then: 1 })).to.be.false();
+        expect(Hoek.isPromise([])).to.be.false();
+
+        const items = [
+            Promise.resolve(),
+            Promise.reject()
+        ];
+
+        expect(Hoek.isPromise(items[0])).to.be.true();
+        expect(Hoek.isPromise(items[1])).to.be.true();
+        expect(Hoek.isPromise(new Promise(Hoek.ignore))).to.be.true();
+        expect(Hoek.isPromise({ then: Hoek.ignore })).to.be.true();
+
+        try {
+            await Promise.all(items);
+        }
+        catch (err) { }
+    });
+});
